Crate aranya_trouble

Crate aranya_trouble 

This crate exports a wrapper type to implement core::error::Error for a third-party type.

Structs

Trouble
A wrapper around some error E so that it implements core::error::Error.