This crate exports a wrapper type to implement core::error::Error for a third-party type.
Structs
- Trouble
- A wrapper around some error
Eso that it implementscore::error::Error.
This crate exports a wrapper type to implement core::error::Error for a third-party type.
E so that it implements core::error::Error.